Drivecycle
==========

Drivecycle is a python package that simulates complex velocity-time profiles for EV while taking into account stop and intersection locations along with speed limits. Drivecycle also simulates battery state of charge given vehicle (i.e. mass, battery type/capacity, etc.) and route (i.e. elevation change) characteristics.